@@ -248,6 +248,7 @@ class LaharFlowData(object):
                 self._get_parameters_from_runinfo()
             self._get_max_depth()
             self._get_max_speed()
+            self._get_max_conc()
             self._get_max_bed_evolution()
     
     def _get_parameters_from_inputfile(self):
@@ -357,6 +358,9 @@ class LaharFlowData(object):
                     if keyword=="Erosion rate":
                         self.ErosionRate = float(value)
                         parameters.append('ErosionRate')
+                    if keyword=="Granular erosion rate":
+                        self.GranularErosionRate = float(value)
+                        parameters.append('GranularErosionRate')
                     if keyword=="Erosion depth":
                         self.ErosionDepth = float(value)
                         parameters.append('ErosionDepth')
@@ -988,6 +992,21 @@ class LaharFlowData(object):
         
         return bt
 
+    def _get_max_conc(self):
+        
+        if 'Maximums.nc' in self.nc_files:
+            LaharFlowFile = self._extract_file('Maximums.nc')
+            try:
+                m = nc_max(LaharFlowFile, 'maximum_concentration')
+                self.MaxConc = m['maximum_depth']
+            except:
+                self.MaxConc = None            
+            return
+        else:
+            print ('make this work')
+            #raise RuntimeWarning('No data to determine maximum depth')
+        return
+
     def _get_max_depth(self):
         
         if 'Maximums.nc' in self.nc_files:
